// @flow

import React from 'react'
import Markdown from 'react-markdown'
import { ThemeProvider } from 'react-css-themr'
import Template from 'components/Template'
import Section from 'components/Section'
import Gallery from 'components/Gallery'
import OptIn from 'components/OptIn'
import Carousel from 'components/Carousel'
import Tabs from 'components/Tabs'
import theme from './theme'

import {
  navItems,
  languages,
  footer,
  copyright,
  summary,
  policy,
  progress,
  images,
  tabs,
} from '../../sample-data/realestate'

const Home = () => (
  <ThemeProvider theme={theme}>
    <Template
      theme={theme}
      items={navItems}
      languages={languages}
      footer={footer}
      copyright={copyright}
      tawkId="5927f86eb3d02e11ecc66f01"
      // renderNavItem={renderNavItem}
    >
      <div className="flex flex-wrap pt5">
        <div className="w-100 flex flex-wrap">
          <Carousel
            className="w-100 w-70-l"
            imagesToShow={1}
            items={images}
            renderItem={({ src }) => (
              <div className="aspect-ratio--16x9" key={src}>
                <img
                  className="absolute"
                  // className="w-100 vh-50 vh-75-l"
                  src={src}
                  alt={src}
                  onLoad={() => {
                    window.dispatchEvent(new Event('resize'))
                  }}
                />
              </div>
            )}
          />
          <div className="flex-ns items-center-ns justify-center-ns w-100 w-30-l -bg-blue pa0 pb4-m">
            <div>
              <h3 className="mb2 -bg-blue white center pa4 tc f3 fw4">Chúng tôi tư vấn miễn phí!</h3>
              <OptIn
                className=""
                requireName
                data={{
                  callToAction: 'Đặt lịch hẹn',
                }}
                theme={{
                  form: 'ph4-ns',
                  body: 'ph4 ph0-ns -bg-blue mb4 mb2-ns',
                  inputWrapper: 'bg-light-gray center ph2 pv2 ba b--light-gray mb2',
                  icon: 'mr2 black-70',
                  input: 'ph3 fw1 f6 black-70 bg-light-gray',
                  callToAction: '-bg-orange fw9 tracked pt3 w-100 ph3 pv4 pv3-ns ph2-ns br2 bn outline-0 flex-none self-stretch white f5 f6-ns',
                  errorWrapper: 'flex flex-wrap',
                  error: 'dn',
                }}
              />
            </div>
          </div>
        </div>
        <Section
          className="w-100 bg-near-white"
          title="Tổng quan"
          subtitle="Dự án Gelexia Riverside"
          theme={{
            body: 'flex flex-wrap mt3 mt3-ns w-90-ns center',
          }}
        >
          <div className="w-100 w-50-ns pa2 ph2-ns order-1">
            <Markdown source={summary} />
          </div>
          <div className="w-100 w-50-ns flex items-center ph2-ns order-0">
            <img src={images[0].src} alt={images[0].src} />
          </div>
        </Section>
        <Section
          className="w-100"
          title="Vị trí"
          subtitle="Gần các trung tâm thương mại lớn"
          theme={{
            body: 'flex flex-wrap',
          }}
        >
          <div className="w-100 w-50-ns">
            <img
              src="http://res.cloudinary.com/alice28/image/upload/v1495943131/vi-tri.png"
              alt="Vị trí dự án"
            />
          </div>
          <div className="w-100 w-50-ns flex items-center ph2-ns">
            <img src={images[0].src} alt={images[0].src} />
          </div>
        </Section>
        <Section
          className="w-100 -bg-pastel pb0 pb5-ns"
          title="Thư viện"
          subtitle="Hình ảnh dự án"
        >
          <Gallery className="w-100 flex flex-wrap" images={images} />
        </Section>
        <Section
          className="w-100"
          title="Mặt bằng"
          theme={{
            body: 'flex flex-wrap mw8 center',
          }}
        >
          <Tabs items={tabs} />
        </Section>
        <Section
          className="w-100 white -bg-blue"
          title="Chính sách & Tiến độ"
          theme={{
            title: 'alfa-slab-one black f2-m f1-l tc f2',
            body: 'flex flex-wrap mw8 center',
          }}
        >
          <div className="w-100 w-50-ns">
            <Markdown source={policy} />
          </div>
          <div className="w-100 w-50-ns ph2-ns">
            <Markdown source={progress} />
          </div>
        </Section>
      </div>
    </Template>
  </ThemeProvider>
)

export default Home
