// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import { Link as BaseLink } from 'react-router'
import cn from 'classnames'

const Link = ({ to, children, className, theme, ...props }: {
  to: string,
  children?: any,
  className?: string,
  theme: { [key: string]: string },
}) => {
  if (!to) {
    return (
      <a
        className={cn('link', className, theme.root)}
        {...props}
      >
        {children}
      </a>
    )
  }

  return (
    <BaseLink
      className={cn('link', className, theme.root)}
      to={to}
      {...props}
    >
      {children}
    </BaseLink>
  )
}

Link.defaultProps = {
  children: null,
  className: undefined,
}

export default themr('Link', {}, { composeTheme: 'softly' })(Link)
