// @flow

import React from 'react'
import { themr } from 'react-css-themr'
import cn from 'classnames'
import Link from 'components/Link'
import LanguageSelector from 'components/LanguageSelector'

const NavDropdown = ({
  items,
  languages = [],
  language,
  onClose,
  theme,
  className,
  renderNavItem,
  ...props
}: {
  items: Array<{
    to: string,
    label: any,
  }>,
  languages: Array<{
    lang: string,
    link: string,
  }>,
  language: string,
  theme: { [key: string]: string },
  className?: string,
  renderNavItem?: (item: any) => any,
  onClose: () => void,
}) => (
  <div className={cn('min-h-100', theme.root, className)} {...props}>
    <div className={theme.body}>
      {items.map(item => (
        renderNavItem ? renderNavItem(item) : (
          <Link
            key={item.to}
            className={theme.item}
            to={item.to}
            onClick={() => onClose()}
          >
            {item.label}
          </Link>
        )
      ))}
      {languages.length > 0 && (
        <LanguageSelector
          selected={language}
          items={languages}
        />
      )}
    </div>
  </div>
)

NavDropdown.defaultProps = {
  className: undefined,
  renderNavItem: null,
}

export default themr('NavDropdown', {}, { composeTheme: 'softly' })(NavDropdown)
