// @flow

import React from 'react'
import { compose, withState, withReducer } from 'recompose'
import cn from 'classnames'
import { themr } from 'react-css-themr'
import Input from 'components/Input'
import Button from 'components/Button'
import createFormReducer from 'utils/createFormReducer'

export const defaultStyles = {
  header: '',
  input: '',
  callToAction: '',
}

const themeConfig = {
  vertical: {
    root: '',
    form: '',
    input: 'w-100',
    callToAction: 'w-100',
  },
  horizontal: {
    root: '',
    form: 'flex items-center',
    input: 'flex-auto',
    callToAction: 'flex-none',
  },
}

const ON_CHANGE = 'ON_CHANGE'

function validateField(name: string, value: string): string {
  switch (name) {
    case 'name':
      if (!value) return 'Required name'
      break
    case 'email':
      if (!value) return 'Required email'
      break
    default:
      return ''
  }
  return ''
}

const reducer = createFormReducer({ ON_CHANGE, validateField })

const OptIn = ({
  data: {
    isHorizontal = false,
    action,
    secret,
    callToAction,
    nameLabel = 'Your Name',
    emailLabel = 'Your Email',
    className,
  } = {},
  requireName = false,
  state: {
    name = '',
    email = '',
    isValid = false,
    error,
  },
  isCheck,
  check,
  dispatch,
  onSubmit,
  theme,
}: {
  data: TOptIn,
  state: {
    name: string,
    email: string,
    error: {
      name?: string,
      email?: string,
    },
    isValid: boolean,
  },
  isCheck: boolean,
  check: (isCheck: boolean) => void,
  requireName?: boolean,
  dispatch: Function,
  onSubmit?: Function,
  theme: { [key: string]: string },
}) => {
  const styleName = isHorizontal ? 'horizontal' : 'vertical'
  const _theme = themeConfig[styleName]

  return (
    <div className={className}>
      <form
        className={_theme.form}
        action={action}
        method="post"
        target="_blank"
      >
        {requireName && (
          <Input
            name="FNAME"
            id="mce-FNAME"
            icon="fa-user"
            className={cn(_theme.input, theme.input)}
            value={name}
            placeholder={nameLabel}
            onChange={(e) => {
              dispatch({ type: ON_CHANGE, payload: { name: 'name', value: e.target.value } })
            }}
          />
        )}
        <Input
          type="email"
          name="EMAIL"
          id="mce-EMAIL"
          icon="fa-envelope"
          className={cn(_theme.input, theme.input)}
          value={email}
          placeholder={emailLabel}
          onChange={(e) => {
            dispatch({ type: ON_CHANGE, payload: { name: 'email', value: e.target.value } })
          }}
        />
        <input
          className="dn"
          aria-hidden="true"
          type="text"
          name={secret}
          tabIndex="-1"
          value=""
        />
        <Button
          className={cn(_theme.callToAction, theme.callToAction)}
          disabled={!isValid}
          onClick={() => {
            check(true)
            if (onSubmit) {
              onSubmit({ email, name })
            }
          }}
        >
          {callToAction}
        </Button>
      </form>
      {isCheck && error.name && (
        <div>
          <div className="-red f7">{error.name}</div>
        </div>
      )}
      {isCheck && error.email && (
        <div>
          <div className="-red f7">{error.email}</div>
        </div>
      )}
    </div>
  )
}

OptIn.defaultProps = {
  header: null,
  className: null,
  error: {},
  onSubmit: null,
  requireName: false,
}

const defaultError = {
  name: 'Required name',
  email: 'Required email',
}

export default compose(
  themr('OptIn', {}, { composeTheme: 'softly' }),
  withState('isCheck', 'check', false),
  withReducer('state', 'dispatch', reducer, { error: defaultError, isValid: false }),
)(OptIn)
