// @flow

import React from 'react'
import cn from 'classnames'
import throttle from 'lodash.throttle'
import { themr } from 'react-css-themr'
import { compose, withState } from 'recompose'
import Transition from 'react-motion-ui-pack'
import Navigation from 'components/Navigation'
import NavDropdown from 'components/NavDropdown'
import Footer from 'components/Footer'

export const defaultStyles = {
  defaultNavWrapper: 'bg-black-30',
  stickyNavWrapper: 'bg-black-30',
}

class Template extends React.Component {
  props: {
    children?: any,
    items: Array<any>,
    language: string,
    languages: Array<any>,
    logo: any,
    footer: any,
    copyright: string,
    isToggleNav: boolean,
    toggleNav: (isToggleNav: boolean) => void,
    isShowNav: boolean,
    showNav: (isShowNav: boolean) => void,
    theme: { [key: string]: any },
    renderNavItem?: (item: any) => any,
  };

  static defaultProps = {
    children: null,
    language: 'vi',
  };

  onScroll = () => {
    if (window.scrollY > 50) {
      this.props.toggleNav(true)
    } else {
      this.props.toggleNav(false)
    }
  }

  componentDidMount() {
    window.addEventListener('scroll', throttle(this.onScroll, 100))
  }

  componentWillUnmount() {
    window.removeEventListener('scroll', () => {})
  }

  render() {
    const {
      isToggleNav,
      showNav,
      isShowNav,
      theme,
      children,
      items,
      language,
      languages,
      logo,
      footer,
      copyright,
      renderNavItem,
    } = this.props
    return (
      <div>
        <div
          className={cn(theme.navWrapper, {
            [theme.defaultNavWrapper]: !isToggleNav,
            [theme.stickyNavWrapper]: isToggleNav,
          })}
        >
          <Navigation
            items={items}
            language={language}
            languages={languages}
            logo={logo}
            show={showNav}
            isShow={isShowNav}
            isSticky={isToggleNav}
            renderNavItem={renderNavItem}
          />
        </div>
        <Transition
          component={false}
          enter={{
            translateY: 0, // spring(0, { stiffness: 80, damping: 10 }),
          }}
          leave={{
            translateY: -2000,
          }}
        >
          {isShowNav && (
            <NavDropdown
              key="dropdown"
              items={items}
              language={language}
              languages={languages}
              renderNavItem={renderNavItem}
              onClose={() => showNav(false)}
            />
          )}
        </Transition>
        {!isShowNav && (
          <div className={theme.bodyWrapper}>
            {children}
          </div>
        )}
        {!isShowNav && (
          <div className={theme.footerWrapper}>
            <Footer
              className={theme.footer}
              data={footer}
            />
          </div>
        )}
        {!isShowNav && (
          <div className={theme.copyrightWrapper}>
            <div className={theme.copyright}>{copyright}</div>
          </div>
        )}
      </div>
    )
  }
}

Template.defaultProps = {
  renderNavItem: null,
  language: 'vi',
}

export default compose(
  themr('Template', {}, { composeTheme: 'softly' }),
  withState('isToggleNav', 'toggleNav', false),
  withState('isShowNav', 'showNav', false),
)(Template)
